Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(138)

Unified Diff: components/test_runner/test_runner.h

Issue 1325953002: Add functions to let tests read and control the Bluetooth chooser state. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@lkcr
Patch Set: Add a forgotten semicolon. :-/ Created 5 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/html_viewer/web_test_delegate_impl.cc ('k') | components/test_runner/test_runner.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/test_runner/test_runner.h
diff --git a/components/test_runner/test_runner.h b/components/test_runner/test_runner.h
index 6b389b1417476b7ef7be9f020e0de8596547a4f9..b8f6284c647c9fc115f4e31938a89e6d1ab6f870 100644
--- a/components/test_runner/test_runner.h
+++ b/components/test_runner/test_runner.h
@@ -521,9 +521,25 @@ class TestRunner : public WebTestRunner,
void SetColorProfile(const std::string& name,
v8::Local<v8::Function> callback);
// Change the bluetooth test data while running a layout test.
void SetBluetoothMockDataSet(const std::string& name);
+ // Makes the Bluetooth chooser record its input and wait for instructions from
+ // the test program on how to proceed.
+ void SetBluetoothManualChooser();
+
+ // Returns the events recorded since the last call to this function.
+ std::vector<std::string> GetBluetoothManualChooserEvents();
+
+ // Calls the BluetoothChooser::EventHandler with the arguments here. Valid
+ // event strings are:
+ // * "cancel" - simulates the user canceling the chooser.
+ // * "select" - simulates the user selecting a device whose device ID is in
+ // |argument|.
+ void SendBluetoothManualChooserEvent(const std::string& event,
+ const std::string& argument);
+
// Enables mock geofencing service while running a layout test.
// |service_available| indicates if the mock service should mock geofencing
// being available or not.
@@ -521,9 +521,25 @@ class TestRunner : public WebTestRunner,
void SetColorProfile(const std::string& name,
v8::Local<v8::Function> callback);
- // Change the bluetooth test data while running a layout test.
+ // Change the bluetooth test data while running a layout test and resets the
+ // chooser to accept the first device.
void SetBluetoothMockDataSet(const std::string& name);
« no previous file with comments | « components/html_viewer/web_test_delegate_impl.cc ('k') | components/test_runner/test_runner.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698